@@ -1,5 +1,5 @@
 /*
- * $Id: abook.c,v 1.36 2002/10/11 11:04:15 jheinonen Exp $
+ * $Id: abook.c,v 1.39 2003/11/06 17:32:00 jheinonen Exp $
  *
  * by JH <jheinonen@users.sourceforge.net>
  *
@@ -137,12 +137,15 @@ init_abook()
 }
 
 void
-quit_abook()
+quit_abook(int save_db)
 {
-	if( opt_get_bool(BOOL_AUTOSAVE) )
-		save_database();
-	else if( statusline_ask_boolean("Save database", TRUE) )
-		save_database();
+	if(save_db)  {
+		if(opt_get_bool(BOOL_AUTOSAVE))
+			save_database();
+		else if(statusline_ask_boolean("Save database", TRUE))
+			save_database();
+	} else if(!statusline_ask_boolean("Quit without saving", FALSE))
+		return;
 
 	free_opts();
 	close_database();
@@ -155,14 +158,14 @@ quit_abook()
 static void
 quit_abook_sig(int i)
 {
-	quit_abook();
+	quit_abook(QUIT_SAVE);
 }
 
 int
 main(int argc, char **argv)
 {
 #if defined(HAVE_SETLOCALE) && defined(HAVE_LOCALE_H)
-	setlocale(LC_ALL, "" );
+	setlocale(LC_ALL, "");
 #endif
 
 	parse_command_line(argc, argv);
@@ -171,7 +174,7 @@ main(int argc, char **argv)
 
 	get_commands();	
 
-	quit_abook();
+	quit_abook(QUIT_SAVE);
 
 	return 0;
 }
@@ -451,7 +454,7 @@ mutt_query(char *str)
 		putchar('\n');
 		while(i >= 0) {
 			muttq_print_item(stdout, i);
-			i = find_item(str, i+1, search_fields);
+			i = find_item(str, i + 1, search_fields);
 		}
 	}
 
@@ -530,8 +533,7 @@ launch_mutt(int item)
 		}
 	}
 
-	cmd = strconcat(mutt_command, " \'", mailstr,
-				"\'", NULL);
+	cmd = strconcat(mutt_command, " \'", mailstr, "\'", NULL);
 	free(mailstr);
 #ifdef DEBUG
 	fprintf(stderr, "cmd: %s\n", cmd);
@@ -578,7 +580,7 @@ abook_malloc(size_t size)
 
 	if ( (ptr = malloc(size)) == NULL ) {
 		if( is_ui_initialized() )
-			quit_abook();
+			quit_abook(QUIT_SAVE);
 		perror("malloc() failed");
 		exit(1);
 	}
@@ -591,12 +593,12 @@ abook_realloc(void *ptr, size_t size)
 {
 	ptr = realloc(ptr, size);
 
-	if( size == 0 )
+	if(size == 0)
 		return NULL;
 
-	if( ptr == NULL ) {
-		if( is_ui_initialized() )
-			quit_abook();
+	if(ptr == NULL) {
+		if(is_ui_initialized())
+			quit_abook(QUIT_SAVE);
 		perror("realloc() failed");
 		exit(1);
 	}
@@ -642,7 +644,7 @@ convert(char *srcformat, char *srcfile, char *dstformat, char *dstfile)
 	init_opts();
 	load_opts(rcfile);
 
-	switch( import_file(srcformat, srcfile) ) {
+	switch(import_file(srcformat, srcfile)) {
 		case -1:
 			fprintf(stderr,
 				"input format %s not supported\n", srcformat);
@@ -655,7 +657,7 @@ convert(char *srcformat, char *srcfile, char *dstformat, char *dstfile)
 	}
 
 	if(!ret)
-		switch( export_file(dstformat, dstfile) ) {
+		switch(export_file(dstformat, dstfile)) {
 			case -1:
 				fprintf(stderr,
 					"output format %s not supported\n",
@@ -775,7 +777,7 @@ add_email(int quiet)
 	char *name = NULL, *email = NULL;
 	struct stat s;
 
-	if( (fstat(fileno(stdin), &s)) == -1 || S_ISDIR(s.st_mode)) {
+	if( (fstat(fileno(stdin), &s)) == -1 || S_ISDIR(s.st_mode) ) {
 		fprintf(stderr, "stdin is a directory or cannot stat stdin\n");
 		exit(1);
 	}
