@@ -1,5 +1,5 @@
 /*
- * $Id: abook_rl.c,v 1.7 2003/05/30 16:51:31 jheinonen Exp $
+ * $Id: abook_rl.c,v 1.8 2003/11/07 07:02:15 jheinonen Exp $
  *
  * by JH <jheinonen@users.sourceforge.net>
  *
@@ -12,7 +12,7 @@
 #include "abook.h"
 #include "abook_rl.h"
 
-#define KEYPAD_HACK 1 /* enable a keypad hack */
+#define KEYPAD_HACK 1 /* enable keypad hack */
 #define CBREAK_HACK 1 /* enable cbreak hack */
 
 #ifdef HAVE_CONFIG_H
