@@ -1,6 +1,6 @@
 
 /*
- * $Id: edit.c,v 1.25 2003/06/04 12:10:10 jheinonen Exp $
+ * $Id: edit.c,v 1.26 2003/11/10 08:45:59 jheinonen Exp $
  *
  * by JH <jheinonen@users.sourceforge.net>
  *
@@ -394,8 +394,10 @@ edit_loop(int item)
 		case 'a': tab = TAB_ADDRESS; break;
 		case 'p': tab = TAB_PHONE; break;
 		case 'o': tab = TAB_OTHER; break;
+		case 'h':
 		case KEY_LEFT: tab = tab == 0 ? MAX_TAB : tab - 1;
 			       break;
+		case 'l':
 		case KEY_RIGHT: tab = tab == MAX_TAB ? 0 : tab + 1;
 				break;
 		case KEY_UP:
