@@ -9,13 +9,15 @@ static char *mainhelp[] = {
 
 "	?		help\n",
 "	q		quit\n",
-"	Q		quit and print selected item(s) to stderr\n",
+"	Q		quit without saving\n",
+"	P		quit and print selected item(s) to stderr\n",
 "	^L		refresh screen\n",
 "\n",
 "	arrows / j,k	scroll list\n",
 "	enter		view/edit item\n",
 "	a		add item\n",
 "	r / del		remove selected items\n",
+"	D		duplicate item\n",
 "\n",
 "	space		select item\n",
 "	+		select all\n",
@@ -32,6 +34,7 @@ static char *mainhelp[] = {
 "\n",
 "	s		sort database\n",
 "	S		\"surname sort\"\n",
+"	F		sort by field (defined in configuration file)\n",
 "\n",
 "	/		find\n",
 "	\\		find next\n",
@@ -48,7 +51,7 @@ NULL
 static char *editorhelp[] = {
 
 "\n",
-"	a,c,p,o / left,right	change tab\n",
+"	a,c,p,o / arrows / h,l	change tab\n",
 "\n",
 "	1 - 5			edit fields\n",
 "\n",
